@@ -192,6 +192,20 @@ class QuantEngineClient:
         # print(order_id)
         return order_id
 
+    def cancel_order(self, order_id: str) -> bool:
+        request = AlgorumWebsocketMessage('cancel_order',
+                                          AlgorumMessageType.Request,
+                                          self.CorIdCounter.increment(),
+                                          jsonpickle.encode(order_id, False), None)
+        # print(request)
+        response = self.execute_async(request)
+
+        if response.MessageType == AlgorumMessageType.ErrorResponse:
+            raise Exception(response.Error['ErrorMessage'])
+
+        result: bool = jsonpickle.decode(response.JsonData)
+        return result
+
     def create_indicator_evaluator(self, create_indicator_request: CreateIndicatorRequest) \
             -> RemoteIndicatorEvaluator:
         request = AlgorumWebsocketMessage('create_indicator_evaluator',
